# Aequitas Core Library

This is a sketch repository for the Aequitas core library. It is a work in progress.
No definite decisions have been made yet.
Feel free to contribute and/or provide feedback in the issue section.
